@@ -1,6 +1,5 @@
 /*
  * md5cmd.h
- * $Id: md5cmd.h 79597 2011-06-19 20:59:11Z jmr@macports.org $
  *
  * Copyright (c) 2002 - 2003 Apple Inc.
  * All rights reserved.
@@ -30,4 +29,4 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-int MD5Cmd(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
+int MD5Cmd(ClientData, Tcl_Interp *, int, Tcl_Obj *const objv[]);
