@@ -1,6 +1,5 @@
 /*
  * sha256cmd.h
- * $Id: sha256cmd.h 84356 2011-09-23 16:08:34Z jmr@macports.org $
  *
  * Copyright (c) 2009 The MacPorts Project
  * All rights reserved.
@@ -38,7 +37,7 @@
 /**
  * A native command for sha256 checksums.
  */
-int SHA256Cmd(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
+int SHA256Cmd(ClientData, Tcl_Interp *, int, Tcl_Obj *const objv[]);
 
 #endif
 	/* _SHA256CMD_H */
