@@ -291,7 +291,7 @@ options configure.perl configure.python configure.ruby \
 default configure.perl              {}
 default configure.python            {}
 default configure.ruby              {}
-default configure.install           {${portutil::autoconf::install_command}}
+default configure.install           {[expr {$system_options(clonebin_path) ne "" ? [file join $system_options(clonebin_path) install] : ${portutil::autoconf::install_command}}]}
 default configure.awk               {}
 default configure.bison             {}
 default configure.pkg_config        {}
@@ -557,11 +557,6 @@ proc portconfigure::configure_get_sdkroot {sdk_version} {
         return {}
     }
 
-    # Special hack for Tiger/ppc, since the system libraries do not contain intel slices
-    if {${os.arch} eq "powerpc" && $macos_version_major eq "10.4" && [variant_exists universal] && [variant_isset universal]} {
-        return ${developer_dir}/SDKs/MacOSX10.4u.sdk
-    }
-
     # Use the DevSDK (eg: /usr/include) if present and the requested SDK version matches the host version
     if {${os.major} < 19 && $sdk_version eq $macos_version_major && [file exists /usr/include/sys/cdefs.h]} {
         return {}
@@ -798,7 +793,25 @@ proc portconfigure::configure_get_default_compiler {} {
     foreach compiler $search_list {
         set allowed yes
         foreach pattern ${compiler.blacklist} {
-            if {[string match $pattern $compiler]} {
+            if {[llength $pattern] >= 3 && [lindex $pattern 0] eq $compiler} {
+                # version based, e.g. {clang < 500}
+                set compiler_vers [compiler.command_line_tools_version $compiler]
+                set allowed no
+                if {$compiler_vers eq {}} {
+                    break
+                }
+                foreach {operator check_vers} [lrange ${pattern} 1 end] {
+                    # matches only if all comparisons are true
+                    if {![vercmp $compiler_vers $operator $check_vers]} {
+                        set allowed yes
+                        break
+                    }
+                }
+                if {!$allowed} {
+                    break
+                }
+            } elseif {[string match $pattern $compiler]} {
+                # pattern based, e.g. *gcc-4.2
                 set allowed no
                 break
             }
@@ -1249,7 +1262,7 @@ proc portconfigure::get_clang_compilers {} {
                 }
             }
 
-            if {${os.major} >= 9 && ${os.major} < 20} {
+            if {${os.major} < 20} {
                 lappend compilers macports-clang-7.0 \
                     macports-clang-6.0 \
                     macports-clang-5.0
@@ -1257,13 +1270,8 @@ proc portconfigure::get_clang_compilers {} {
 
             if {${os.major} < 16} {
                 # The Sierra SDK requires a toolchain that supports class properties
-                if {${os.major} >= 9} {
-                    lappend compilers macports-clang-3.7
-                }
-                lappend compilers macports-clang-3.4
-                if {${os.major} < 9} {
-                    lappend compilers macports-clang-3.3
-                }
+                lappend compilers macports-clang-3.7 \
+                        compilers macports-clang-3.4
             }
 
         }
@@ -1857,7 +1865,7 @@ proc portconfigure::configure_main {args} {
             append_to_environment_value configure "__CFPREFERENCES_AVOID_DAEMON" 1
         }
 
-        # add SDK flags if cross-compiling (or universal on ppc tiger)
+        # add SDK flags if needed
         if {${configure.sdkroot} ne "" && !${compiler.limit_flags}} {
             foreach env_var {CPPFLAGS CFLAGS CXXFLAGS OBJCFLAGS OBJCXXFLAGS} {
                 append_to_environment_value configure $env_var -isysroot${configure.sdkroot}
